@@ -2,6 +2,8 @@ import hashlib
 import json
 from logging import getLogger
 
+from semantic_version import Version
+
 from django.conf import settings
 from django.db import models
 from django.db.models import UniqueConstraint, Q
@@ -46,7 +48,7 @@ class Role(Content):
 
     namespace = models.CharField(max_length=64)
     name = models.CharField(max_length=64)
-    version = models.CharField(max_length=128)
+    version = models.CharField(max_length=128, db_collation="pulp_ansible_semver")
 
     @property
     def relative_path(self):
@@ -175,9 +177,14 @@ class CollectionVersion(Content):
     name = models.CharField(max_length=64, editable=False)
     namespace = models.CharField(max_length=64, editable=False)
     repository = models.CharField(default="", blank=True, max_length=2000, editable=False)
-    version = models.CharField(max_length=128, editable=False)
     requires_ansible = models.CharField(null=True, max_length=255)
 
+    version = models.CharField(max_length=128, db_collation="pulp_ansible_semver")
+    version_major = models.IntegerField()
+    version_minor = models.IntegerField()
+    version_patch = models.IntegerField()
+    version_prerelease = models.CharField(max_length=128)
+
     is_highest = models.BooleanField(editable=False, default=False)
 
     # Foreign Key Fields
@@ -196,6 +203,15 @@ class CollectionVersion(Content):
     #   search_vector is built.
     search_vector = psql_search.SearchVectorField(default="")
 
+    @hook(BEFORE_SAVE)
+    def calculate_version_parts(self):
+        v = Version(self.version)
+
+        self.version_major = v.major
+        self.version_minor = v.minor
+        self.version_patch = v.patch
+        self.version_prerelease = ".".join(v.prerelease)
+
     @property
     def relative_path(self):
         """
@@ -317,7 +333,13 @@ class AnsibleNamespaceMetadata(Content):
     @property
     def avatar_artifact(self):
         if self.avatar_sha256:
-            return self._artifacts.get(sha256=self.avatar_sha256)
+            avatar = self._artifacts.filter(sha256=self.avatar_sha256).first()
+            if avatar is None:
+                log.debug(
+                    f"Artifact({self.avatar_sha256}) is missing for namespace avatar "
+                    f"{self.name}:{self.metadata_sha256}"
+                )
+            return avatar
 
         return None
 
@@ -372,6 +394,19 @@ class DownloadLog(BaseModel):
     )
 
 
+class CollectionDownloadCount(BaseModel):
+    """
+    Aggregate count of downloads per collection
+    """
+
+    namespace = models.CharField(max_length=64, editable=False, db_index=True)
+    name = models.CharField(max_length=64, editable=False, db_index=True)
+    download_count = models.BigIntegerField(default=0)
+
+    class Meta:
+        unique_together = ("namespace", "name")
+
+
 class RoleRemote(Remote, AutoAddObjPermsMixin):
     """
     A Remote for Ansible content.
@@ -384,11 +419,6 @@ class RoleRemote(Remote, AutoAddObjPermsMixin):
         permissions = [("manage_roles_roleremote", "Can manage roles on role remotes")]
 
 
-def _get_last_sync_task(pk):
-    sync_tasks = Task.objects.filter(name__contains="sync", reserved_resources_record__icontains=pk)
-    return sync_tasks.order_by("-pulp_created").first()
-
-
 class CollectionRemote(Remote, AutoAddObjPermsMixin):
     """
     A Remote for Collection content.
@@ -423,10 +453,6 @@ class CollectionRemote(Remote, AutoAddObjPermsMixin):
             self._download_factory = AnsibleDownloaderFactory(self)
             return self._download_factory
 
-    @property
-    def last_sync_task(self):
-        return _get_last_sync_task(self.pk)
-
     @hook(
         AFTER_UPDATE,
         when_any=["url", "requirements_file", "sync_dependencies", "signed_only"],
@@ -499,10 +525,6 @@ class AnsibleRepository(Repository, AutoAddObjPermsMixin):
     gpgkey = models.TextField(null=True)
     private = models.BooleanField(default=False)
 
-    @property
-    def last_sync_task(self):
-        return _get_last_sync_task(self.pk)
-
     class Meta:
         default_related_name = "%(app_label)s_%(model_name)s"
 
