@@ -27,6 +27,9 @@ ANSIBLE_SIGNING_TASK_LIMITER = 10
 ANSIBLE_DEFAULT_DISTRIBUTION_PATH = None
 ANSIBLE_URL_NAMESPACE = ""
 ANSIBLE_COLLECT_DOWNLOAD_LOG = False
+ANSIBLE_COLLECT_DOWNLOAD_COUNT = False
+ANSIBLE_AUTHENTICATION_CLASSES = settings.REST_FRAMEWORK["DEFAULT_AUTHENTICATION_CLASSES"]
+ANSIBLE_PERMISSION_CLASSES = settings.REST_FRAMEWORK["DEFAULT_PERMISSION_CLASSES"]
 
 DRF_ACCESS_POLICY = {
     "dynaconf_merge_unique": True,
