@@ -8,13 +8,13 @@ from pulp_smash.utils import http_get
 from pulpcore.client.pulp_ansible import (
     AnsibleCollectionsApi,
     ContentCollectionVersionsApi,
-    ApiException,
 )
 
 from pulp_ansible.tests.functional.utils import gen_ansible_client
 from pulp_ansible.tests.functional.utils import set_up_module as setUpModule  # noqa:F401
 
 
+# TODO: Check if this url will stay around
 COLLECTION_URL = "https://galaxy.ansible.com/download/pulp-squeezer-0.0.9.tar.gz"
 
 
@@ -52,13 +52,6 @@ class UploadCollectionTestCase(PulpTestCase):
         * `Pulp #5262 <https://pulp.plan.io/issues/5262>`_
         """
         response = self.upload_collection()
-
         self.assertEqual(response.sha256, self.collection_sha256, response)
 
-        with self.assertRaises(ApiException) as exc:
-            self.upload_collection()
-
-        assert exc.exception.status == 400
-        assert "Artifact already exists" in exc.exception.body
-
         delete_orphans()
