@@ -13,18 +13,12 @@ from pulp_smash import api, config
 from pulp_smash.pulp3.utils import gen_distribution, gen_repo
 from pulp_smash.utils import http_get
 
-from requests.exceptions import HTTPError
-
 from pulp_ansible.tests.functional.constants import (
     ANSIBLE_COLLECTION_FILE_NAME,
     ANSIBLE_COLLECTION_UPLOAD_FIXTURE_URL,
     ANSIBLE_DISTRIBUTION_PATH,
     ANSIBLE_REPO_PATH,
 )
-from pulp_ansible.tests.functional.utils import set_up_module as setUpModule  # noqa:F401
-from pulp_smash.pulp3.bindings import delete_orphans
-from pulp_smash.pulp3.bindings import monitor_task
-
 from orionutils.generator import build_collection
 
 
@@ -243,6 +237,7 @@ def test_collection_detail(collection_artifact, collection_detail, pulp_dist):
     assert collection_detail["namespace"] == collection_artifact.namespace
     assert collection_detail["name"] == collection_artifact.name
     assert collection_detail["highest_version"]["version"] == "1.0.0"
+    assert collection_detail["download_count"] == 0
 
 
 def test_collection_version_list(
@@ -259,7 +254,7 @@ def test_collection_version_list(
 
 
 def test_collection_version_filter_by_q(
-    pulp_client, pulp_dist, ansible_collection_version_api_client
+    pulp_client, pulp_dist, ansible_collection_version_api_client, monitor_task, delete_orphans_pre
 ):
     """Verify successive imports do not aggregate tags into search vectors."""
 
@@ -273,9 +268,6 @@ def test_collection_version_filter_by_q(
         resp = ansible_collection_version_api_client.create(**body)
         monitor_task(resp.task)
 
-    # required for sequential runs to get around constraint errors
-    delete_orphans()
-
     # make&publish 2 collections with each having unique tags
     specs = [("tag1", "ns1", "col1"), ("tag2", "ns1", "col2")]
     for spec in specs:
@@ -362,16 +354,10 @@ def test_collection_download(collection_artifact, pulp_client, collection_detail
 
 
 def test_collection_upload_repeat(pulp_client, collection_artifact, pulp_dist, collection_upload):
-    """Upload a duplicate collection.
-
-    Should fail, because of the conflict of collection name and version.
     """
-    with pytest.raises(HTTPError) as ctx:
-        upload_collection(pulp_client, collection_artifact.filename, pulp_dist["base_path"])
-
-    assert ctx.value.response.json()["errors"][0] == {
-        "status": "400",
-        "code": "invalid",
-        "title": "Invalid input.",
-        "detail": "Artifact already exists",
-    }
+    Upload a duplicate collection.
+    """
+    response = upload_collection(pulp_client, collection_artifact.filename, pulp_dist["base_path"])
+    assert response["error"] is None
+    assert response["state"] == "completed"
+    assert re.match(r"[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}", response["id"])
