@@ -490,7 +490,6 @@ def create_repos_and_dists(
     return created_dists, created_repos
 
 
-@pytest.mark.pulp_on_localhost
 @pytest.fixture()
 def search_specs(
     tmp_path,
@@ -762,16 +761,12 @@ class TestCrossRepoSearchFilters:
 
         comparison = compare_keys(skeys, rkeys)
 
-        # import epdb; epdb.st()
-
         assert len(skeys) == len(rkeys), comparison
 
-    @pytest.mark.pulp_on_localhost
     def test_collection_version_search_all(self, galaxy_v3_default_search_api_client, search_specs):
         """Get everything."""
         self._run_search(galaxy_v3_default_search_api_client, search_specs, [], {})
 
-    @pytest.mark.pulp_on_localhost
     def test_collection_version_search_by_pulp_label(
         self, galaxy_v3_default_search_api_client, search_specs
     ):
@@ -783,7 +778,6 @@ class TestCrossRepoSearchFilters:
             {"repository_label": "special"},
         )
 
-    @pytest.mark.pulp_on_localhost
     def test_collection_version_search_by_pulp_label_value(
         self, galaxy_v3_default_search_api_client, search_specs
     ):
@@ -795,7 +789,6 @@ class TestCrossRepoSearchFilters:
             {"repository_label": "galaxy_type=sync_repo"},
         )
 
-    @pytest.mark.pulp_on_localhost
     def test_collection_version_search_by_repoid(
         self, galaxy_v3_default_search_api_client, search_specs
     ):
@@ -812,7 +805,6 @@ class TestCrossRepoSearchFilters:
             {"repository": repo_ids},
         )
 
-    @pytest.mark.pulp_on_localhost
     def test_collection_version_search_by_base_path(
         self, galaxy_v3_default_search_api_client, search_specs
     ):
@@ -828,7 +820,6 @@ class TestCrossRepoSearchFilters:
             {"distribution_base_path": base_paths},
         )
 
-    @pytest.mark.pulp_on_localhost
     def test_collection_version_search_by_distid(
         self, galaxy_v3_default_search_api_client, search_specs
     ):
@@ -844,7 +835,6 @@ class TestCrossRepoSearchFilters:
             {"distribution": dist_ids},
         )
 
-    @pytest.mark.pulp_on_localhost
     def test_collection_version_search_by_namespace(
         self, galaxy_v3_default_search_api_client, search_specs
     ):
@@ -856,7 +846,6 @@ class TestCrossRepoSearchFilters:
             {"namespace": "foo"},
         )
 
-    @pytest.mark.pulp_on_localhost
     def test_collection_version_search_by_name(
         self, galaxy_v3_default_search_api_client, search_specs
     ):
@@ -869,7 +858,6 @@ class TestCrossRepoSearchFilters:
         )
 
     # @pytest.mark.skip(reason="pulp_ansible includes pre-releases in is_highest")
-    @pytest.mark.pulp_on_localhost
     def test_collection_version_search_by_highest(
         self, galaxy_v3_default_search_api_client, search_specs
     ):
@@ -881,7 +869,6 @@ class TestCrossRepoSearchFilters:
             {"highest": True},
         )
 
-    @pytest.mark.pulp_on_localhost
     def test_collection_version_search_by_q(
         self, galaxy_v3_default_search_api_client, search_specs
     ):
@@ -893,7 +880,6 @@ class TestCrossRepoSearchFilters:
             {"q": "gifts"},
         )
 
-    @pytest.mark.pulp_on_localhost
     def test_collection_version_search_by_keywords(
         self, galaxy_v3_default_search_api_client, search_specs
     ):
@@ -905,7 +891,6 @@ class TestCrossRepoSearchFilters:
             {"keywords": "gifts"},
         )
 
-    @pytest.mark.pulp_on_localhost
     def test_collection_version_search_by_dependency(
         self, galaxy_v3_default_search_api_client, search_specs
     ):
@@ -917,7 +902,6 @@ class TestCrossRepoSearchFilters:
             {"dependency": "foo.bar"},
         )
 
-    @pytest.mark.pulp_on_localhost
     def test_collection_version_search_by_version(
         self, galaxy_v3_default_search_api_client, search_specs
     ):
@@ -929,7 +913,6 @@ class TestCrossRepoSearchFilters:
             {"version": "1.0.1"},
         )
 
-    @pytest.mark.pulp_on_localhost
     def test_collection_version_search_by_deprecated(
         self, galaxy_v3_default_search_api_client, search_specs
     ):
@@ -941,7 +924,6 @@ class TestCrossRepoSearchFilters:
             {"deprecated": True},
         )
 
-    @pytest.mark.pulp_on_localhost
     def test_collection_version_search_by_not_deprecated(
         self, galaxy_v3_default_search_api_client, search_specs
     ):
@@ -953,7 +935,6 @@ class TestCrossRepoSearchFilters:
             {"deprecated": False},
         )
 
-    @pytest.mark.pulp_on_localhost
     def test_collection_version_search_by_signed(
         self, galaxy_v3_default_search_api_client, search_specs
     ):
@@ -965,7 +946,6 @@ class TestCrossRepoSearchFilters:
             {"signed": True},
         )
 
-    @pytest.mark.pulp_on_localhost
     def test_collection_version_search_by_not_signed(
         self, galaxy_v3_default_search_api_client, search_specs
     ):
@@ -1389,3 +1369,187 @@ def test_cross_repo_search_index_on_deleted_distro_with_another_still_remaining(
         limit=1000, repository_name=[pulp_repo.name], repository_version="latest"
     )
     assert resp.meta.count == 1
+
+
+def test_cross_repo_search_index_on_distribution_with_repository_and_deprecation(
+    ansible_collection_deprecations_api_client,
+    ansible_distro_api_client,
+    ansible_repo_api_client,
+    ansible_repo_version_api_client,
+    build_and_upload_collection,
+    galaxy_v3_collections_api_client,
+    galaxy_v3_default_search_api_client,
+    gen_object_with_cleanup,
+    monitor_task,
+):
+    """Make sure indexes are marking deprecations."""
+
+    pulp_repo = gen_object_with_cleanup(ansible_repo_api_client, {"name": str(uuid.uuid4())})
+    col = build_and_upload_collection(ansible_repo=pulp_repo)
+
+    # make a distro that points only at the latest repo version ...
+    distro = gen_object_with_cleanup(
+        ansible_distro_api_client,
+        {
+            "name": pulp_repo.name,
+            "base_path": pulp_repo.name,
+            "repository": pulp_repo.pulp_href,
+        },
+    )
+
+    # make a deprecation
+    namespace = col[0].namespace
+    name = col[0].name
+    monitor_task(
+        galaxy_v3_collections_api_client.update(
+            name,
+            namespace,
+            pulp_repo.name,
+            {"deprecated": True},
+        ).task
+    )
+
+    # make sure the CV was indexed
+    dist_id = distro.pulp_href.split("/")[-2]
+    resp = galaxy_v3_default_search_api_client.list(limit=1000, distribution=[dist_id])
+    assert resp.meta.count == 1, resp
+
+    # did it get properly marked as deprecated?
+    assert resp.data[0].is_deprecated, resp
+
+
+def test_cross_repo_search_index_with_updated_namespace_metadata(
+    add_to_cleanup,
+    ansible_distro_api_client,
+    ansible_namespaces_api_client,
+    ansible_repo_api_client,
+    build_and_upload_collection,
+    galaxy_v3_collections_api_client,
+    galaxy_v3_default_search_api_client,
+    galaxy_v3_plugin_namespaces_api_client,
+    gen_object_with_cleanup,
+    monitor_task,
+    random_image_factory,
+):
+    """Make sure namespace metdata updates are reflected in the index."""
+
+    # make a repo
+    pulp_repo = gen_object_with_cleanup(ansible_repo_api_client, {"name": str(uuid.uuid4())})
+
+    # make a distro that points at the repository
+    distro = gen_object_with_cleanup(
+        ansible_distro_api_client,
+        {
+            "name": pulp_repo.name,
+            "base_path": pulp_repo.name,
+            "repository": pulp_repo.pulp_href,
+        },
+    )
+    dist_id = distro.pulp_href.split("/")[-2]
+    distro_kwargs = {"path": distro.base_path, "distro_base_path": distro.base_path}
+
+    # define col namespace
+    namespace_name = randstr()
+
+    # define col name
+    collection_name = randstr()
+
+    # make namespace metadata
+    task = galaxy_v3_plugin_namespaces_api_client.create(
+        name=namespace_name, description="hello", company="Testing Co.", **distro_kwargs
+    )
+    result = monitor_task(task.task)
+    namespace_href = [x for x in result.created_resources if "namespaces" in x][0]
+    add_to_cleanup(galaxy_v3_plugin_namespaces_api_client, namespace_href)
+
+    # make and publish a collection
+    build_and_upload_collection(
+        ansible_repo=pulp_repo, config={"namespace": namespace_name, "name": collection_name}
+    )
+
+    # make sure the CV was indexed
+    resp = galaxy_v3_default_search_api_client.list(limit=1000, distribution=[dist_id])
+    assert resp.meta.count == 1, resp
+
+    # did it get all the metadata?
+    cv = resp.data[0]
+    assert cv.namespace_metadata.pulp_href == namespace_href
+    assert cv.namespace_metadata.avatar_url is None
+    # assert cv.namespace_metadata.avatar_sha256 is None
+    assert cv.namespace_metadata.company == "Testing Co."
+    assert cv.namespace_metadata.description == "hello"
+    assert cv.namespace_metadata.name == namespace_name
+
+    # update the namespace metadata with an avatar
+    avatar_path = random_image_factory()
+    task2 = galaxy_v3_plugin_namespaces_api_client.create(
+        name=namespace_name,
+        description="hello 2",
+        company="Testing Co. redux",
+        avatar=avatar_path,
+        **distro_kwargs,
+    )
+    result2 = monitor_task(task2.task)
+    namespace2_href = [x for x in result2.created_resources if "namespaces" in x][0]
+    add_to_cleanup(galaxy_v3_plugin_namespaces_api_client, namespace2_href)
+
+    # make sure the CV was re-indexed
+    resp2 = galaxy_v3_default_search_api_client.list(limit=1000, distribution=[dist_id])
+    assert resp2.meta.count == 1, resp2
+
+    # did it get all the NEW metadata?
+    cv2 = resp2.data[0]
+    assert cv2.namespace_metadata.pulp_href == namespace2_href
+    assert cv2.namespace_metadata.avatar_url is not None
+    # assert cv2.namespace_metadata.avatar_sha256 is not None
+    assert cv2.namespace_metadata.company == "Testing Co. redux"
+    assert cv2.namespace_metadata.description == "hello 2"
+    assert cv2.namespace_metadata.name == namespace_name
+
+
+def test_cross_repo_search_semantic_version_ordering(
+    ansible_distro_api_client,
+    ansible_repo_api_client,
+    build_and_upload_collection,
+    galaxy_v3_default_search_api_client,
+    gen_object_with_cleanup,
+):
+    """Make sure collections are properly sorted using the order_by='version' parameter."""
+    pulp_repo = gen_object_with_cleanup(ansible_repo_api_client, {"name": str(uuid.uuid4())})
+
+    gen_object_with_cleanup(
+        ansible_distro_api_client,
+        {
+            "name": pulp_repo.name,
+            "base_path": pulp_repo.name,
+            "repository": pulp_repo.pulp_href,
+        },
+    )
+
+    versions = [
+        "2.0.0",
+        "1.22.2",
+        "1.22.1",
+        "1.22.1-rc",
+        "1.22.1-pre",
+        "1.22.1-dev",
+        "1.22.1-beta",
+        "1.22.1-alpha",
+        "1.1.0",
+        "1.0.1",
+        "1.0.0",
+    ]
+
+    for version in versions:
+        build_and_upload_collection(ansible_repo=pulp_repo, config={"version": version})
+
+    resp = galaxy_v3_default_search_api_client.list(
+        limit=1000, order_by=["-version"], repository_name=[pulp_repo.name]
+    )
+
+    built_collection_versions = [col.collection_version.version for col in resp.data]
+
+    # Make sure versions are correctly sorted according to Semantic Versioning.
+    assert versions == sorted(versions, key=Version, reverse=True)
+
+    assert versions == built_collection_versions
