@@ -1,8 +1,6 @@
 """Utilities for tests for the ansible plugin."""
 from dynaconf import Dynaconf
 from functools import partial
-from time import sleep
-import os
 import unittest
 from urllib.parse import urlparse, parse_qs
 
@@ -30,7 +28,6 @@ from pulp_ansible.tests.functional.constants import (
 from pulpcore.client.pulpcore import (
     ApiClient as CoreApiClient,
     TasksApi,
-    SigningServicesApi,
     StatusApi,
 )
 from pulpcore.client.pulp_ansible import (
@@ -44,12 +41,9 @@ from pulpcore.client.pulp_ansible import (
     RemotesGitApi,
     RemotesRoleApi,
     AnsibleRepositorySyncURL,
-    PulpAnsibleArtifactsCollectionsV3Api,
     RepositoriesAnsibleVersionsApi,
 )
 
-from orionutils.generator import build_collection, randstr
-
 
 cfg = config.get_config()
 configuration = cfg.get_bindings_config()
@@ -156,61 +150,6 @@ identical, except that ``exc`` has been set to ``unittest.SkipTest``.
 
 core_client = CoreApiClient(configuration)
 tasks = TasksApi(core_client)
-signing = SigningServicesApi(core_client)
-
-
-def wait_tasks():
-    """Polls the Task API until all tasks are in a completed state."""
-    running_tasks = tasks.list(state="running")
-    while running_tasks.count:
-        sleep(1)
-        running_tasks = tasks.list(state="running")
-
-
-def gen_collection_in_distribution(
-    base_path, name=None, namespace=None, versions=None, **cfg_kwargs
-):
-    """
-    Generate a randomized collection and upload it to the specified repository.
-
-    Params:
-        - base_path: distribtion base path for the repository to upload the
-          collection to.
-        - name: Name of the collection. If none is provided a random name will
-          be generated.
-        - namespace: Namespace of the collection. If none is provided a random
-          name will be generated.
-        - versions: A list of versions to create for the collection. If none
-          are specified the collection will be generated with version 1.0.0
-
-        Additional galaxy.yaml configuration options can be added as kwargs.
-        For example dependencies={"foo.bar": "1.0.0"} will set foo.bar as a
-        dependency for the newly generated collection
-
-    Returns: a dictionary with the name and namespace names of the newly generated
-    collection.
-    """
-    if versions is None:
-        versions = ["1.0.0"]
-    namespace = namespace or randstr()
-    name = name or randstr()
-
-    ansible_client = gen_ansible_client()
-    upload = PulpAnsibleArtifactsCollectionsV3Api(ansible_client)
-
-    for version in versions:
-        artifact = build_collection(
-            "skeleton",
-            config={"namespace": namespace, "name": name, "version": version, **cfg_kwargs},
-        )
-
-        upload.create(path=base_path, file=artifact.filename)
-
-        wait_tasks()
-
-        os.remove(artifact.filename)
-
-    return {"name": name, "namespace": namespace}
 
 
 class TestCaseUsingBindings(PulpTestCase):
@@ -333,23 +272,6 @@ settings = Dynaconf(
 )
 
 
-def get_psql_smash_cmd(sql_statement):
-    """
-    Generate a command in a format for pulp smash cli client to execute the specified SQL statement.
-
-    The implication is that PostgreSQL is always running on localhost.
-    Args:
-        sql_statement(str): An SQL statement to execute.
-    Returns:
-        tuple: a command in the format for  pulp smash cli client
-    """
-    host = "localhost"
-    user = settings.DATABASES["default"]["USER"]
-    password = settings.DATABASES["default"]["PASSWORD"]
-    dbname = settings.DATABASES["default"]["NAME"]
-    return ("psql", "-c", sql_statement, f"postgresql://{user}:{password}@{host}/{dbname}")
-
-
 def iterate_all(list_func, **kwargs):
     """
     Iterate through all of the items on every page in a paginated list view.
